@@ -193,10 +193,11 @@ class Graph(object):
     def __str__(self):
         result = str()
         result += '\n' + self.id + ':'
-        for s in self.to_dict():
+        triples = self.to_dict()
+        for s in triples:
             result += '\n - ' + str(s) + ':'
-            for p in self.dictionary[s]:
+            for p in triples[s]:
                 result += '\n  - ' + str(p)
-                for o in self.dictionary[s][p]:
+                for o in triples[s][p]:
                     result += '\n   - ' + str(o)
         return result
\ No newline at end of file
